@@ -9,9 +9,9 @@ import os
 import sys
 
 from mobio.libs.Singleton import Singleton
-from mobio.sdk.base.common import CONSTANTS
-from mobio.sdk.base.common.system_config import SystemConfig
-from mobio.sdk.base.configs import LoggingConfig, ApplicationConfig
+from mobio.sdks.base.common import CONSTANTS
+from mobio.sdks.base.common.system_config import SystemConfig
+from mobio.sdks.base.configs import LoggingConfig, ApplicationConfig
 from logstash_formatter import LogstashFormatterV1
 
 
@@ -24,6 +24,7 @@ class LOGGING:
     FILE_MAX_BYTES = "file_max_bytes"
     FILE_BACKUP_COUNT = "file_backup_count"
 
+
 @Singleton
 class MobioLogging:
     def __init__(self):
